@@ -28,13 +28,11 @@
 
 #include "eventview.h"
 
-#include <KDateTime>
+#include <QDateTime>
 
 class KCheckableProxyModel;
 
-namespace EventViews
-{
-
+namespace EventViews {
 class EventViewPrivate
 {
 public: /// Methods
@@ -56,10 +54,10 @@ public: /// Members
     KCheckableProxyModel *collectionSelectionModel;
 
     QByteArray identifier;
-    KDateTime startDateTime;
-    KDateTime endDateTime;
-    KDateTime actualStartDateTime;
-    KDateTime actualEndDateTime;
+    QDateTime startDateTime;
+    QDateTime endDateTime;
+    QDateTime actualStartDateTime;
+    QDateTime actualEndDateTime;
 
     /* When we receive a QEvent with a key_Return release
      * we will only show a new event dialog if we previously received a
@@ -68,7 +66,7 @@ public: /// Members
     bool mReturnPressed;
     bool mDateRangeSelectionEnabled;
     bool mTypeAhead;
-    QObject *mTypeAheadReceiver;
+    QObject *mTypeAheadReceiver = nullptr;
     QList<QEvent *> mTypeAheadEvents;
     static CalendarSupport::CollectionSelection *sGlobalCollectionSelection;
 
@@ -76,11 +74,10 @@ public: /// Members
     PrefsPtr mPrefs;
     KCalPrefsPtr mKCalPrefs;
 
-    Akonadi::IncidenceChanger *mChanger;
+    Akonadi::IncidenceChanger *mChanger = nullptr;
     EventView::Changes mChanges;
     Akonadi::Collection::Id mCollectionId;
 };
-
 } // EventViews
 
 #endif
